==> kutil-1.10.3-sources.jar: de/bixilon/kutil/primitive/BooleanUtil.kt <==
/*
 * KUtil
 * Copyright (C) 2021 Moritz Zwerger
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package de.bixilon.kutil.primitive

object BooleanUtil {

    fun Any?.toBoolean(): Boolean {
        return when (this) {
            is Boolean -> this
            is Number -> this.toInt() == 0x01
            "true" -> true
            "false" -> false
            else -> throw IllegalArgumentException("Unknown boolean value: $this")
        }
    }

    fun <T> Boolean.decide(`true`: T, `false`: T): T {
        return if (this) {
            `true`
        } else {
            `false`
        }
    }

    fun <T> Boolean.decide(`true`: () -> T, `false`: () -> T): T {
        return if (this) {
            `true`()
        } else {
            `false`()
        }
    }

    fun <T> Boolean.decide(`true`: T, `false`: () -> T): T {
        return if (this) {
            `true`
        } else {
            `false`()
        }
    }

    fun <T> Boolean.decide(`true`: () -> T, `false`: T): T {
        return if (this) {
            `true`()
        } else {
            `false`
        }
    }

    val Boolean.one: Int get() = if (this) 1 else -1
}

==> kutil-1.24.3-sources.jar: de/bixilon/kutil/primitive/BooleanUtil.kt <==
/*
 * KUtil
 * Copyright (C) 2021-2022 Moritz Zwerger
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package de.bixilon.kutil.primitive

object BooleanUtil {

    fun Any?.toBoolean(): Boolean {
        return when (this) {
            is Boolean -> this
            is Number -> this.toInt() == 0x01
            "true" -> true
            "false" -> false
            else -> throw IllegalArgumentException("Unknown boolean value: $this")
        }
    }

    inline fun <T> Boolean.decide(`true`: T, `false`: T): T {
        return if (this) {
            `true`
        } else {
            `false`
        }
    }

    inline fun <T> Boolean.decide(`true`: () -> T, `false`: () -> T): T {
        return if (this) {
            `true`()
        } else {
            `false`()
        }
    }

    inline fun <T> Boolean.decide(`true`: T, `false`: () -> T): T {
        return if (this) {
            `true`
        } else {
            `false`()
        }
    }

    inline fun <T> Boolean.decide(`true`: () -> T, `false`: T): T {
        return if (this) {
            `true`()
        } else {
            `false`
        }
    }

    inline val Boolean.one: Int get() = if (this) 1 else -1
}
